jcson - enhanced json for configuration
========================================

Introdcution
------------
The jcson python module is an enhanced json parser, that supports:

* path expression sustitutions, a way of referring to other parts of the json/dictionary tree
* include directive
* new line and inline comments